@@ -1,7 +1,7 @@
 #
 #	Gnu.pm --- The GNU Readline/History Library wrapper module
 #
-#	$Id: Gnu.pm 507 2016-03-01 15:50:25Z hayashi $
+#	$Id: Gnu.pm 513 2016-03-06 00:39:56Z hayashi $
 #
 #	Copyright (c) 1996 Hiroo Hayashi.  All rights reserved.
 #
@@ -86,7 +86,7 @@ END
     use DynaLoader;
     our ($VERSION, @ISA, @EXPORT_OK);
 
-    $VERSION = '1.30';		# update Gnu::XS::VERSION also.
+    $VERSION = '1.31';		# update Gnu::XS::VERSION also.
 
     # Term::ReadLine::Gnu::AU makes a function in
     # `Term::ReadLine::Gnu::XS' as a method.
@@ -1017,7 +1017,7 @@ Manual|http://cnswww.cns.cwru.edu/php/chet/readline/readline.html>.
 
 =item C<get_function_name(FUNCTION)>
 
-	str	rl_get_function_name(FunctionPtr function)	# TRG orignal
+	str	rl_get_function_name(FunctionPtr function)	# TRG original
 
 =item C<function_of_keyseq(KEYMAP [,MAP])>
 
